#
# spec file for package perl-Pod-Spell
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Pod-Spell
Name:           perl-Pod-Spell
Version:        1.26
Release:        1.8
License:        Artistic-2.0
Summary:        Formatter for spellchecking Pod
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/H/HA/HAARG/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Class::Tiny)
BuildRequires:  perl(File::ShareDir)
BuildRequires:  perl(File::ShareDir::Install) >= 0.06
BuildRequires:  perl(Lingua::EN::Inflect)
BuildRequires:  perl(Pod::Escapes)
BuildRequires:  perl(Pod::Simple) >= 3.27
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(parent)
Requires:       perl(Class::Tiny)
Requires:       perl(File::ShareDir)
Requires:       perl(Lingua::EN::Inflect)
Requires:       perl(Pod::Escapes)
Requires:       perl(Pod::Simple) >= 3.27
Requires:       perl(parent)
%{perl_requires}

%description
Pod::Spell is a Pod formatter whose output is good for spellchecking.
Pod::Spell is rather like Pod::Text, except that it doesn't put much effort
into actual formatting, and it suppresses things that look like Perl
symbols or Perl jargon (so that your spellchecking program won't complain
about mystery words like "'$thing'" or "'Foo::Bar'" or "hashref").

This class works by filtering out words that look like Perl or any form of
computerese (like "'$thing'" or "'N>7'" or "'@{$foo}{'bar','baz'}'",
anything in C<...> or F<...> codes, anything in verbatim paragraphs (code
blocks), and anything in the stopword list. The default stopword list for a
document starts out from the stopword list defined by Pod::Wordlist, and
can be supplemented (on a per-document basis) by having '"=for stopwords"'
/ '"=for :stopwords"' region(s) in a document.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING README
%license LICENSE

%changelog
* Tue Mar 14 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.26
  see /usr/share/doc/packages/perl-Pod-Spell/Changes
  1.26      2023-03-13
  - encode output as UTF-8
* Wed Oct  5 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.25
  see /usr/share/doc/packages/perl-Pod-Spell/Changes
  1.25      2022-10-04
  - releasing as stable
  1.24      2022-10-03 (TRIAL RELEASE)
  - account for stopwords added in UTF-8 encoded form
* Thu Sep 22 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.23
  see /usr/share/doc/packages/perl-Pod-Spell/Changes
  1.23      2022-09-21
  - releasing as stable
  1.22      2022-08-29 (TRIAL RELEASE)
  - fix finding wordlist when not run against files directly in lib/
  1.21      2022-08-24 (TRIAL RELEASE)
  - port to use Pod::Simple rather than Pod::Parser
  - use File::Spec rather than Path::Tiny
  - allow explicit debug option to override environment variable
  - packaging and metadata updates
* Wed Oct 28 2020 Dirk Stoecker <opensuse@dstoecker.de>
- update specfile with cpanspec to fix build
* Thu May  5 2016 coolo@suse.com
- updated to 1.20
  see /usr/share/doc/packages/perl-Pod-Spell/Changes
  1.20      2016-04-22
  - Stable release, made in Rugby, UK during Perl QA Hackathon 2016
  1.19_91   2016-04-21
  - Drop use of File::ShareDir::ProjectDistDir (GitHub #26). Thanks Kent
  Fredric!
  - Allow stop words with '.' (GitHub #28). Thanks Paulo Custodio!
  1.19_90   2016-02-20
  - Hide internals: the POD parser is moved to a private package and
  the Pod::Spell package now only exposes the public interface.
  This is a first step towards rewriting the parser using Pod::Simple
  (planned for Pod-Spell-2.0).
  - 'parse_from_file' and 'parse_from_filehandle' are now explicitely
  documented (by copying doc from Pod::Parser).
* Sun Feb 21 2016 coolo@suse.com
- updated to 1.19
  see /usr/share/doc/packages/perl-Pod-Spell/Changes
  1.19      2016-02-20
  - Don't set $Text::Wrap::huge globally, but localize it
  - Load Pod::Wordlist only if used
* Sun Feb  7 2016 coolo@suse.com
- updated to 1.18
  see /usr/share/doc/packages/perl-Pod-Spell/Changes
  1.18      2016-01-30
  - New maintainer: Olivier Mengué (DOLMEN)
  Repo is now hosted at github.com/perl-pod/Pod-Spell
  - Fix warning in strip_stopwords (GH #23)
  - re-apply "podspell script: set output encoding from locale CTYPE"
  (GH #22, #17). The issue in 1.16 was an incorrect dependency
  on I18N::Langinfo.
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.17
  see /usr/share/doc/packages/perl-Pod-Spell/Changes
  1.17      2015-03-08
  - revert changes in 1.16 they are not compatible with windows GH #18
  1.16      2015-02-24
  - podspell script: set output encoding from locale CTYPE (DOLMEN)
* Mon Sep 15 2014 coolo@suse.com
- updated to 1.15
  - Convert to strict mode of File::ShareDir::ProjectDistDir (KENTNL)
  - change to use Path::Tiny->lines_utf8
  - Discontinue use of File::Slurp, use Path::Tiny->lines instead
    GH #15 ( Ether )
* Tue Nov 26 2013 coolo@suse.com
- updated to 1.13
  - fix encoding issues issues in pod for perldoc
  - improve documentation
  - fix shebang to /usr/bin/perl for EUMM replacment GH #13 (dolmen)
* Fri Oct  4 2013 coolo@suse.com
- updated to 1.10
    [FEATURES]
  - added 'no_wide_chars' option to strip words with such characters
    from the output.  This may help spellcheckers that can't cope
    with UTF-8
    [CHANGED]
  - improved punctuation stripping algorithm for better word
    isolation (example C<< "hello". >> now is found as "hello")
  - strips all word that do not have at least one \w character
    as a spellchecker isn't likely to do anything useful with them
    [DOCUMENTED]
  - added recommendations for dealing with character encoding
  1.09      2013-09-25
    [FIXED]
  - stopwords with 's are learned without 's to match how they are
    checked
    [CHANGED]
  - leading and trailing punctuation is entirely stripped since the
    spellchecker won't care anyway.  Trailing periods are *not*
    stripped as they might be abbreviations ("Ph.D."), but such words
    are checked against the stoplist both with and without
    trailing periods to account for abbreviations and words at the
    end of a sentence.
  1.08      2013-09-24
    [FIXED]
  - hyphenated word parts are also checked against the stoplist
    and stripped (dagolden) GH #9
    [DOCUMENTED]
  - noted that stopwords must be added before words appear in Pod
  1.07      2013-09-14
  - add many words
    [FEATURES]
  - Pod::Wordlist is an Object ( dagolden )
  - Lingua::EN::Inflect is used to reduce requiring plurals in the list
    ( dagolden )
  - the wordlist is now a sharedir file
    [DEPRECATED]
  - accessing %%Pod::Wordlist::Wordlist directly
  1.06      2013-09-08
  - import stopwords from Pod::Wordlist::hanekomu except names
* Sat Jul 27 2013 coolo@suse.com
- updated to 1.05
  - add stopwords
* Mon Jun 10 2013 coolo@suse.com
- updated to 1.04
  - fix tests to work on older perls
  - update copyright info
  - require 5.8 (let me know if this is a problem for you)
  - improve tests
  - hopefully fix failing test on windows
  - improve code readability
  - remove DEBUG for private _is_debug method
  - convert to dzil and adopt
* Wed Feb 27 2013 coolo@suse.com
- update license to new format
* Tue Dec 21 2010 coolo@novell.com
- change license tag to the usual perl license
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Jul 14 2010 chris@computersalat.de
- initial package 1.01
  * created by cpanspec 1.78
